rst2pyi
=======

Convert reStructuredText annotations to .pyi type stubs

[![build status](https://travis-ci.org/jreese/rst2pyi.svg?branch=master)](https://travis-ci.org/jreese/rst2pyi)
[![code coverage](https://img.shields.io/coveralls/github/jreese/rst2pyi/master.svg)](https://coveralls.io/github/jreese/rst2pyi)
[![version](https://img.shields.io/pypi/v/rst2pyi.svg)](https://pypi.org/project/rst2pyi)
[![license](https://img.shields.io/pypi/l/rst2pyi.svg)](https://github.com/jreese/rst2pyi/blob/master/LICENSE)
[![code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


License
-------

rst2pyi is copyright [John Reese](https://jreese.sh), and licensed under
the MIT license.  I am providing code in this repository to you under an open
source license.  This is my personal repository; the license you receive to
my code is from me and not from my employer. See the `LICENSE` file for details.
